==> film_gyaan-1.0.1.tar.gz: lib/src/dx/_endpoints/objects/watch_provider_tv.dart <==
// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

class WatchProvidersTv extends Result {
  WatchProvidersTv({
    required this.results,
  });

  factory WatchProvidersTv.fromJson(String str) =>
      WatchProvidersTv.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory WatchProvidersTv.fromMap(Map<String, dynamic> json) =>
      WatchProvidersTv(
        results: List<WatchProvidersTvResult>.from(
          (json['results'] as List<dynamic>).map<dynamic>(
                (dynamic x) => WatchProvidersTvResult.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
      );

  List<WatchProvidersTvResult> results;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
    'results': List<Map<String, dynamic>>.from(
      results.map<Map<String, dynamic>>(
            (x) => x.toMap(),
      ),
    ),
  };
}

class WatchProvidersTvResult {
  WatchProvidersTvResult({
    required this.displayPriority,
    required this.logoPath,
    required this.providerName,
    required this.providerId,
  });

  factory WatchProvidersTvResult.fromJson(String str) =>
      WatchProvidersTvResult.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory WatchProvidersTvResult.fromMap(Map<String, dynamic> json) =>
      WatchProvidersTvResult(
        displayPriority: json['display_priority'] as int? ?? 0,
        logoPath: json['logo_path'] as String? ?? '',
        providerName: json['provider_name'] as String? ?? '',
        providerId: json['provider_id'] as int? ?? 0,
      );

  int displayPriority;
  String logoPath;
  String providerName;
  int providerId;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
    'display_priority': displayPriority,
    'logo_path': logoPath,
    'provider_name': providerName,
    'provider_id': providerId,
  };
}

==> film_gyaan-1.0.2.tar.gz: lib/src/dx/_endpoints/objects/watch_provider_tv.dart <==
// coverage:ignore-file
import 'dart:convert';

import 'package:film_gyaan/core.dart';

/// @nodoc
class WatchProvidersTv extends Result {
  WatchProvidersTv({
    required this.results,
  });

  factory WatchProvidersTv.fromJson(String str) => WatchProvidersTv.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory WatchProvidersTv.fromMap(Map<String, dynamic> json) =>
      WatchProvidersTv(
        results: List<WatchProvidersTvResult>.from(
          (json['results'] as List<dynamic>).map<dynamic>(
            (dynamic x) => WatchProvidersTvResult.fromMap(
              x as Map<String, dynamic>,
            ),
          ),
        ),
      );

  List<WatchProvidersTvResult> results;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'results': List<Map<String, dynamic>>.from(
          results.map<Map<String, dynamic>>(
            (x) => x.toMap(),
          ),
        ),
      };
}

class WatchProvidersTvResult {
  WatchProvidersTvResult({
    required this.displayPriority,
    required this.logoPath,
    required this.providerName,
    required this.providerId,
  });

  factory WatchProvidersTvResult.fromJson(String str) =>
      WatchProvidersTvResult.fromMap(
        json.decode(str) as Map<String, dynamic>,
      );

  factory WatchProvidersTvResult.fromMap(Map<String, dynamic> json) =>
      WatchProvidersTvResult(
        displayPriority: json['display_priority'] as int? ?? 0,
        logoPath: json['logo_path'] as String? ?? '',
        providerName: json['provider_name'] as String? ?? '',
        providerId: json['provider_id'] as int? ?? 0,
      );

  int displayPriority;
  String logoPath;
  String providerName;
  int providerId;

  String toJson() => json.encode(toMap());

  Map<String, dynamic> toMap() => <String, dynamic>{
        'display_priority': displayPriority,
        'logo_path': logoPath,
        'provider_name': providerName,
        'provider_id': providerId,
      };
}
